@@ -3,9 +3,9 @@ import json
 from qtpy.QtCore import QObject, Signal
 from qtpy.QtGui import QFontDatabase
 
-from .FlowTheme import FlowTheme_Toy, FlowTheme_DarkTron, FlowTheme_Ghost, FlowTheme_Blender, \
+from .flows.FlowTheme import FlowTheme_Toy, FlowTheme_DarkTron, FlowTheme_Ghost, FlowTheme_Blender, \
     FlowTheme_Simple, FlowTheme_Ueli, FlowTheme_PureDark, FlowTheme, FlowTheme_PureLight, \
-    FlowTheme_Colorful, FlowTheme_ColorfulLight, FlowTheme_Industrial
+    FlowTheme_Colorful, FlowTheme_ColorfulLight, FlowTheme_Industrial, FlowTheme_Fusion
 from .GlobalAttributes import Location
 
 
@@ -63,6 +63,7 @@ class Design(QObject):
             FlowTheme_PureLight(),
             FlowTheme_ColorfulLight(),
             FlowTheme_Industrial(),
+            FlowTheme_Fusion(),
         ]
 
     def load_from_config(self, filepath: str):
